@@ -9,7 +9,7 @@ use DynaLoader();
 use Carp ();
 @ISA = qw(DynaLoader);
 
-$VERSION = '3.0001_3';
+$VERSION = '3.0002_1';
 
 bootstrap DBD::mysql $VERSION;
 
@@ -29,7 +29,7 @@ sub driver{
 				   'Version' => $VERSION,
 				   'Err'    => \$DBD::mysql::err,
 				   'Errstr' => \$DBD::mysql::errstr,
-				   'Attribution' => 'DBD::mysql by Rudy Lippan'
+				   'Attribution' => 'DBD::mysql by Rudy Lippan and Patrick Galbraith'
 				 });
 
     $drh;
@@ -740,22 +740,25 @@ disallow LOCAL.)
 
 =item Prepared statement support (server side prepare)
 
-To use server side prepared statements, all you need to do is set the variable 
-mysql_server_prepare in the connect:
+As of 3.0002_1, server side prepare statements are on by default (if your
+server is >= 4.1.3)
+
+To use driver emulated prepared statements, all you need to do is set the variable 
+mysql_emulated_prepare in the connect:
 
 $dbh = DBI->connect(
-                    "DBI:mysql:database=test;host=localhost:mysql_server_prepare=1",
+                    "DBI:mysql:database=test;host=localhost;mysql_emulated_prepare=1",
                     "",
                     "",
                     { RaiseError => 1, AutoCommit => 1 }
                     );
 
+* Note: delimiter for this param is ';'
+
 To make sure that the 'make test' step tests whether server prepare works, you just
 need to export the env variable MYSQL_SERVER_PREPARE:
 
-export MYSQL_SERVER_PREPARE=1
-
-Test first without server side prepare, then with.
+export MYSQL_EMULATED_PREPARE=1
 
 
 =item mysql_embedded_options
